@@ -1,6 +1,6 @@
 # App::hopen: Implementation of the hopen(1) program
 package App::hopen;
-our $VERSION = '0.000012'; # TRIAL
+our $VERSION = '0.000014';
 
 # Imports {{{1
 use strict; use warnings;
@@ -9,8 +9,9 @@ use Data::Hopen::Base;
 use App::hopen::AppUtil ':all';
 use App::hopen::BuildSystemGlobals;
 use App::hopen::Phases qw(:default phase_idx next_phase);
+use App::hopen::Util qw(isMYH MYH);
 use App::hopen::Util::String qw(line_mark_string);
-use Data::Hopen qw(:default loadfrom isMYH MYH $VERBOSE $QUIET);
+use Data::Hopen qw(:default loadfrom *VERBOSE *QUIET);
 use Data::Hopen::Scope::Hash;
 use Data::Hopen::Scope::Environment;
 use Data::Hopen::Util::Data qw(dedent forward_opts);
@@ -116,6 +117,11 @@ See L<App::hopen> and L<App::hopen::Conventions> for more details.
 Specify the architecture.  This is an arbitrary string interpreted by the
 generator or toolset.
 
+=item --build
+
+Run the generator to process the blueprint files.  Cannot be used
+with C<--fresh>.
+
 =item -e C<Perl code>
 
 Add the C<Perl code> as if it were a hopen file.  C<-e> files are processed
@@ -125,22 +131,24 @@ by those files.  Can be specified more than once.
 =item --fresh
 
 Start a fresh build --- ignore any C<MY.hopen.pl> file that may exist in
-the destination directory.
+the destination directory.  Cannot be used with C<--build>.
 
 =item --from C<project dir>
 
 Specify the project directory.  Overrides a project directory given as a
 positional argument.
 
-=item -g C<generator>
+=item -g C<generator> (or -G)
 
 Specify the generator.  The given C<generator> should be either a full package
-name or the part after C<App::hopen::Gen::>.
+name or the part after C<App::hopen::Gen::>.  Also accepts C<-G> to ease
+the transition from cmake.
 
-=item -t C<toolset>
+=item -t C<toolset> (or -T)
 
 Specify the toolset.  The given C<toolset> should be either a full package
-name or the part after C<App::hopen::T::>.
+name or the part after C<App::hopen::T::>.  Also accepts C<-T> to ease
+the transition from cmake.
 
 =item --to C<destination dir>
 
@@ -179,6 +187,8 @@ errors.  *(TODO change this to support LaTeX multi-run files?)*  Then the DAG
 is traversed, and each operation writes the necessary information to the
 file being generated.
 
+=head1 INTERNAL DATA
+
 =cut
 
 # }}}1
@@ -206,6 +216,31 @@ L<App::hopen::HopenFileKit/_language_import>.
 
 our $RUNNING;
 
+=head2 C<$_hrData>
+
+The hashref of the current data we have built up by processing hopen files.
+
+=cut
+
+our $_hrData;   # the hashref of current data
+
+=head2 C<$_did_set_phase>
+
+Set to truthy if MY.hopen.pl sets the phase.
+
+=cut
+
+our $_did_set_phase = false;
+    # Whether the current hopen file called set_phase()
+
+=head2 C<$_hf_pkg_idx>
+
+Used to give each hopen file or C<-e> a unique package name.
+
+=cut
+
+my $_hf_pkg_idx = 0;    # unique ID for the packages of hopen files
+
 # }}}1
 # === Command line parsing ============================================== {{{1
 
@@ -272,6 +307,10 @@ my %CMDLINE_OPTS = (
 
 );
 
+=head1 INTERNAL FUNCTIONS
+
+=cut
+
 sub _parse_command_line { # {{{2
 
 =head2 _parse_command_line
@@ -327,13 +366,13 @@ values from the command line, keyed by the keys in L</%CMDLINE_OPTS>.
         Pod::Usage::pod2usage(-verbose => 1, -exitval => EXIT_OK, @in)
             if have('h');
 
-        # --man: suppress "INTERNALS" section.  Note that this does
+        # --man: suppress "INTERNAL" sections.  Note that this does
         # get rid of the automatic pager we would otherwise get
         # by virtue of pod2usage's invoking perldoc(1).  Oh well.
 
         Pod::Usage::pod2usage(
-            -exitval => EXIT_OK, @in,
-            -verbose => 99, -sections => '!INTERNALS'   # suppress INTERNALS
+            -exitval => EXIT_OK, @in,   # VVV see Pod::Select for format
+            -verbose => 99, -sections => '!INTERNAL.*'
         ) if have('man');
     }
 
@@ -361,24 +400,6 @@ values from the command line, keyed by the keys in L</%CMDLINE_OPTS>.
 # }}}1
 # === Main worker code ================================================== {{{1
 
-=head2 $_hrData
-
-The hashref of the current data we have built up by processing hopen files.
-
-=cut
-
-our $_hrData;   # the hashref of current data
-
-=head2 $_did_set_phase
-
-Set to truthy if MY.hopen.pl sets the phase.
-
-=cut
-
-our $_did_set_phase = false;
-    # Whether the current hopen file called set_phase()
-
-my $_hf_pkg_idx = 0;    # unique ID for the packages of hopen files
 
 sub _execute_hopen_file {       # Load and run a single hopen file {{{2
 
@@ -512,6 +533,9 @@ turned into a C<use lib> statement (see L<lib>) in the generated source.
 
     # -- Build the package
 
+    # TODO move phase-setting to App::hopen::MYhopen
+    # TODO set $App::hopen::MYhopen::IsMYH to indicate whether or not this
+    # file is MY.hopen.pl.
     my $src = line_mark_string <<EOT ;
 {
     package __Rpkg_$pkg_name;
@@ -686,8 +710,7 @@ be run if it is empty.
     $scope->local(true);    # ... but not copied by local-scope calls.
 
     # Run the DAG
-    my $result_data = $Build->run(-context => $scope, -phase => $Phase,
-                                    -visitor => $Generator);
+    my $result_data = $Build->run(-context => $scope, -visitor => $Generator);
     hlog { Data::Dumper->new([$result_data], ['Build graph result data'])->Indent(1)->Dump } 2;
     return $result_data;
 } #_run_phase() }}}2
@@ -716,7 +739,8 @@ The return value of _inner is unspecified and ignored.
     }
 
     if($opts{PRINT_VERSION}) {  # print version, raw and dotted
-        if($App::hopen::VERSION =~ m<^([^\.]+)\.(\d{3})(\d{3})>) {
+        my $ver = $VERSION;
+        if($ver =~ m<^([^\.]+)\.(\d{3})(\d{3})>) {
             printf "hopen version %d.%d.%d ($App::hopen::VERSION)\n", $1, $2, $3;
         } else {
             say "hopen $VERSION";
@@ -850,6 +874,7 @@ EOT
 
     # Handle --build, now that everything's loaded --------------
     if($opts{BUILD}) {
+        # TODO? make sure we're in the right phase?
         $Generator->run_build();
         return;
     }
@@ -867,8 +892,7 @@ EOT
         $new_data = $_hrData;
     }
 
-    $Generator->finalize(-phase => $Phase, -dag => $Build,
-        -data => $new_data);
+    $Generator->finalize(-dag => $Build, -data => $new_data);
         # TODO RESUME HERE - figure out how the generator works into this.
 
     # = Save state in MY.hopen.pl for the next run ==========================
@@ -932,11 +956,17 @@ Command-line runner.  Call as C<< App::hopen::Main(\@ARGV) >>.
 
     my $lrArgs = shift // [];
 
-    # = Process options =====================================================
+    # = Process options ================================================= {{{2
 
     my %opts;
     _parse_command_line(from => $lrArgs, into => \%opts);
 
+    # Check for mutually-inconsistent options
+    if($opts{FRESH} && $opts{BUILD}) {
+        print STDERR '--fresh and --build cannot be used together';
+        return EXIT_PARAM_ERR;
+    }
+
     # Verbosity is the max of -v and --verbose
     $opts{VERBOSE} = $opts{VERBOSE2} if $opts{VERBOSE2} > $opts{VERBOSE};
 
@@ -958,12 +988,12 @@ Command-line runner.  Call as C<< App::hopen::Main(\@ARGV) >>.
 
     delete @opts{qw(VERBOSE VERBOSE2)};
         # After this, code only refers to $QUIET for consistency.
-    # After th
 
     # Don't print the source of an eval'ed hopen file unless -vvv or higher.
     # Need 3 for the "..." that Carp prints when truncating.
     $Carp::MaxEvalLen = 3 unless $VERBOSE >= 3;
 
+    # }}}2
     # = Do it, Rockapella! ==================================================
 
     $RUNNING = true;
@@ -997,7 +1027,7 @@ You can find documentation for this module with the perldoc command.
 
     perldoc App::hopen                      For command-line options
     perldoc App::hopen::Conventions         For terminology and workflow
-    perldoc Data::Hopen                     For internals
+    perldoc Data::Hopen                     For the underlying engine
 
 You can also look for information at:
 
