@@ -4,7 +4,7 @@ use Data::Hopen;
 use strict; use warnings;
 use Data::Hopen::Base;
 
-our $VERSION = '0.000012'; # TRIAL
+our $VERSION = '0.000014'; # TRIAL
 
 use parent 'App::hopen::G::Cmd';
 use Class::Tiny qw(dest linker);
@@ -12,17 +12,10 @@ use Class::Tiny qw(dest linker);
 use App::hopen::BuildSystemGlobals;   # For $DestDir.
     # TODO make the dirs available to nodes through the context.
 use App::hopen::Util::BasedPath;
-#use Config;
 use Data::Hopen qw(getparameters);
-#use Data::Hopen::G::GraphBuilder;
 use Data::Hopen::Util::Filename;
-#use Deep::Hash::Utils qw(deepvalue);
-#use File::Which ();
 use Path::Class;
 
-#my $FN = Data::Hopen::Util::Filename->new;     # for brevity
-#our $_CC;   # Cached compiler name
-
 # Docs {{{1
 
 =head1 NAME
@@ -66,10 +59,10 @@ Create the link command line.
 =cut
 
 sub _run {
-    my ($self, %args) = getparameters('self', [qw(phase visitor ; *)], @_);
+    my ($self, %args) = getparameters('self', [qw(visitor ; *)], @_);
 
     # Currently we only do things at gen time.
-    return $self->passthrough(-nocontext=>1) if $args{phase} ne 'Gen';
+    return $self->passthrough(-nocontext=>1) if $Phase ne 'Gen';
 
     # Pull the inputs
     my $lrObjFiles = $self->input_assets;
